@@ -23,6 +23,7 @@
 #include <QFileInfo>
 #include <QDateTime>
 #include <QDebug>
+#include <QRegularExpression>
 
 #include <QThread>
 #include <QCoreApplication>
@@ -108,20 +109,20 @@ const QVariantList Tagging::get(const QString &queryTxt, std::function<bool(QVar
 bool Tagging::tagExists(const QString &tag, const bool &strict) 
 {
     return !strict ? this->db()->checkExistance(TAG::TABLEMAP[TAG::TABLE::TAGS], FMH::MODEL_NAME[FMH::MODEL_KEY::TAG], tag)
-            : this->db()->checkExistance(QString("select t.tag from APP_TAGS where t.org = '%1' and t.tag = '%2'")
+            : this->db()->checkExistance(QString(QStringLiteral("select t.tag from APP_TAGS where t.org = '%1' and t.tag = '%2'"))
             .arg(this->appOrg, tag));
 }
 
 bool Tagging::urlTagExists(const QString &url, const QString &tag) 
 {
-    return this->db()->checkExistance(QString("select * from TAGS_URLS where url = '%1' and tag = '%2'").arg(url, tag));
+    return this->db()->checkExistance(QString(QStringLiteral("select * from TAGS_URLS where url = '%1' and tag = '%2'")).arg(url, tag));
 }
 
 void Tagging::setApp()
 {
     this->appName = qApp->applicationName();
     this->appComment = QString();
-    this->appOrg = qApp->organizationDomain().isEmpty() ? QString("org.maui.%1").arg(this->appName) : qApp->organizationDomain();
+    this->appOrg = qApp->organizationDomain().isEmpty() ? QString(QStringLiteral("org.maui.%1")).arg(this->appName) : qApp->organizationDomain();
     this->app(); // here register the app
 }
 
@@ -130,7 +131,7 @@ bool Tagging::tag(const QString &tag, const QString &color, const QString &comme
     if (tag.isEmpty())
         return false;
     
-    if(tag.contains(" ") || tag.contains("\n"))
+    if(tag.contains(QStringLiteral(" ")) || tag.contains(QStringLiteral("\n")))
     {
         return false;
     }
@@ -151,7 +152,7 @@ bool Tagging::tag(const QString &tag, const QString &color, const QString &comme
 
     if (this->db()->insert(TAG::TABLEMAP[TAG::TABLE::APP_TAGS], appTag_map)) {
         setTagIconName(tag_map);
-        emit this->tagged(tag_map);
+        Q_EMIT this->tagged(tag_map);
         return true;
     }
 
@@ -176,7 +177,7 @@ bool Tagging::tagUrl(const QString &url, const QString &tag, const QString &colo
     if(this->db()->insert(TAG::TABLEMAP[TAG::TABLE::TAGS_URLS], tag_url_map))
     {
         qDebug() << "tagging url" << url <<tag;
-        emit this->urlTagged(url, myTag);
+        Q_EMIT this->urlTagged(url, myTag);
         
         //         auto fileMetaData = KFileMetaData::UserMetaData(QUrl::fromUserInput(url).toLocalFile());
         //         fileMetaData.setTags({tag});
@@ -206,42 +207,42 @@ bool Tagging::updateUrl(const QString &url, const QString &newUrl)
 
 QVariantList Tagging::getUrlsTags(const bool &strict)  //all used tags, meaning, all tags that are used with an url in tags_url table
 {
-    const auto query = !strict ? QString("select distinct t.* from TAGS t inner join TAGS_URLS turl where t.tag = turl.tag order by t.tag asc") :
-                                 QString("select distinct t.* from TAGS t inner join APP_TAGS at on at.tag = t.tag inner join TAGS_URLS turl on t.tag = turl.tag where at.org = '%1' order by t.tag asc").arg(this->appOrg);
+    const auto query = !strict ? QString(QStringLiteral("select distinct t.* from TAGS t inner join TAGS_URLS turl where t.tag = turl.tag order by t.tag asc")) :
+                                 QString(QStringLiteral("select distinct t.* from TAGS t inner join APP_TAGS at on at.tag = t.tag inner join TAGS_URLS turl on t.tag = turl.tag where at.org = '%1' order by t.tag asc")).arg(this->appOrg);
 
     return this->get(query, &setTagIconName);
 }
 
 bool Tagging::setTagIconName(QVariantMap &item)
 {
-    item.insert("icon", item.value("tag").toString() == "fav" ? "love" : "tag");
+    item.insert(QStringLiteral("icon"), item.value(QStringLiteral("tag")).toString() == QStringLiteral("fav") ? QStringLiteral("love") : QStringLiteral("tag"));
     return true;
 }
 
 QVariantList Tagging::getAllTags(const bool &strict) 
 {
-    return !strict ? this->get("select * from tags", &setTagIconName)
-                   : this->get(QString("select t.* from TAGS t inner join APP_TAGS at on t.tag = at.tag where at.org = '%1'").arg(this->appOrg),
+    return !strict ? this->get(QStringLiteral("select * from tags"), &setTagIconName)
+                   : this->get(QString(QStringLiteral("select t.* from TAGS t inner join APP_TAGS at on t.tag = at.tag where at.org = '%1'")).arg(this->appOrg),
                                &setTagIconName);
 }
 
 QVariantList Tagging::getUrls(const QString &tag, const bool &strict, const int &limit, const QString &mimeType, std::function<bool(QVariantMap &item)> modifier)
 {
-    return !strict ? this->get(QString("select distinct * from TAGS_URLS where tag = '%1' and mime like '%2%' limit %3").arg(tag, mimeType, QString::number(limit)), modifier)
-                   : this->get(QString("select distinct turl.*, t.color, t.comment as tagComment from TAGS t "
-                                       "inner join APP_TAGS at on t.tag = at.tag "
-                                       "inner join TAGS_URLS turl on turl.tag = t.tag "
-                                       "where at.org = '%1' and turl.mime like '%4%' "
-                                       "and t.tag = '%2' limit %3")
+    return !strict ? this->get(QString(QStringLiteral("select distinct * from TAGS_URLS where tag = '%1' and mime like '%2%' limit %3")).arg(tag, mimeType, QString::number(limit)), modifier)
+                   : this->get(QString(QStringLiteral("select distinct turl.*, t.color, t.comment as tagComment from TAGS t "
+                                                      "inner join APP_TAGS at on t.tag = at.tag "
+                                                      "inner join TAGS_URLS turl on turl.tag = t.tag "
+                                                      "where at.org = '%1' and turl.mime like '%4%' "
+                                                      "and t.tag = '%2' limit %3"))
                                .arg(this->appOrg, tag, QString::number(limit), mimeType),
                                modifier);
 }
 
 QVariantList Tagging::getUrlTags(const QString &url, const bool &strict)
 {
-    return !strict ? this->get(QString("select distinct turl.*, t.color, t.comment as tagComment from tags t inner join TAGS_URLS turl on turl.tag = t.tag where turl.url  = '%1'").arg(url))
-                   : this->get(QString("select distinct t.* from TAGS t inner join APP_TAGS at on t.tag = at.tag inner join TAGS_URLS turl on turl.tag = t.tag "
-                                       "where at.org = '%1' and turl.url = '%2'")
+    return !strict ? this->get(QString(QStringLiteral("select distinct turl.*, t.color, t.comment as tagComment from tags t inner join TAGS_URLS turl on turl.tag = t.tag where turl.url  = '%1'")).arg(url))
+                   : this->get(QString(QStringLiteral("select distinct t.* from TAGS t inner join APP_TAGS at on t.tag = at.tag inner join TAGS_URLS turl on turl.tag = t.tag "
+                                                      "where at.org = '%1' and turl.url = '%2'"))
                                .arg(this->appOrg, url));
 }
 
@@ -257,7 +258,7 @@ bool Tagging::removeUrlTag(const QString &url, const QString &tag)
     FMH::MODEL data {{FMH::MODEL_KEY::URL, url}, {FMH::MODEL_KEY::TAG, tag}};
     if(this->db()->remove(TAG::TABLEMAP[TAG::TABLE::TAGS_URLS], data))
     {
-        emit this->urlTagRemoved(tag, url);
+        Q_EMIT this->urlTagRemoved(tag, url);
         return true;
     }
     
@@ -268,7 +269,7 @@ bool Tagging::removeUrl(const QString &url)
 {
     if(this->db()->remove(TAG::TABLEMAP[TAG::TABLE::TAGS_URLS], {{FMH::MODEL_KEY::URL, url}}))
     {
-        emit this->urlRemoved(url);
+        Q_EMIT this->urlRemoved(url);
     }
     
     return false;
@@ -310,7 +311,7 @@ bool Tagging::removeTag(const QString& tag, const bool &strict)
             {
                 if(this->db()->remove(TAG::TABLEMAP[TAG::TABLE::TAGS], data1))
                 {
-                    emit this->tagRemoved(tag);
+                    Q_EMIT this->tagRemoved(tag);
                     return true;
                 }
             }
@@ -324,13 +325,18 @@ bool Tagging::removeTag(const QString& tag, const bool &strict)
 
 static bool doNameFilter(const QString &name, const QStringList &filters)
 {
-    const auto filtersAccumulate = std::accumulate(filters.constBegin(), filters.constEnd(), QVector<QRegExp> {}, [](QVector<QRegExp> &res, const QString &filter) -> QVector<QRegExp> {
-            res.append(QRegExp(filter, Qt::CaseInsensitive, QRegExp::Wildcard));
+    const auto filtersAccumulate = std::accumulate(filters.constBegin(), filters.constEnd(), QVector<QRegularExpression> {}, [](QVector<QRegularExpression> &res, const QString &filter) -> QVector<QRegularExpression> {
+            QString wildcardExp = QRegularExpression::wildcardToRegularExpression(filter).replace(QStringLiteral("[^/]"), QStringLiteral("."));
+            QRegularExpression reg(wildcardExp, QRegularExpression::CaseInsensitiveOption);
+            res.append(reg);
             return res;
 });
     
     for (const auto &filter : filtersAccumulate) {
-        if (filter.exactMatch(name)) {
+        qDebug() << "trying to match" << name << filter;
+        if (filter.match(name).hasMatch()) {
+            qDebug() << "trying to match" << true;
+
             return true;
         }
     }
@@ -344,17 +350,22 @@ QList<QUrl> Tagging::getTagUrls(const QString &tag, const QStringList &filters,
     std::function<bool(QVariantMap & item)> filter = nullptr;
     
     if (!filters.isEmpty())
-        filter = [filters](QVariantMap &item) -> bool {
+    {
+        filter = [filters](QVariantMap &item) -> bool
+        {
             return doNameFilter(FMH::mapValue(item, FMH::MODEL_KEY::URL), filters);
         };
+    }
     
     const auto tagUrls = getUrls(tag, strict, limit, mime, filter);
-    for (const auto &data : tagUrls) {
+    for (const auto &data : tagUrls)
+    {
         const auto url = QUrl(data.toMap()[FMH::MODEL_NAME[FMH::MODEL_KEY::URL]].toString());
         if (url.isLocalFile() && !FMH::fileExists(url))
             continue;
         urls << url;
     }
+
     return urls;
 }
 
@@ -363,14 +374,15 @@ FMH::MODEL_LIST Tagging::getTags(const int &limit)
     Q_UNUSED(limit);
     FMH::MODEL_LIST data;
     const auto tags = getAllTags(false);
-    for (const auto &tag : tags) {
+    for (const auto &tag : tags)
+    {
         const QVariantMap item = tag.toMap();
         const auto label = item.value(FMH::MODEL_NAME[FMH::MODEL_KEY::TAG]).toString();
         
         data << FMH::MODEL {{FMH::MODEL_KEY::PATH, FMStatic::PATHTYPE_URI[FMStatic::PATHTYPE_KEY::TAGS_PATH] + label},
-        {FMH::MODEL_KEY::ICON, item.value(FMH::MODEL_NAME[FMH::MODEL_KEY::ICON], "tag").toString()},
+        {FMH::MODEL_KEY::ICON, item.value(FMH::MODEL_NAME[FMH::MODEL_KEY::ICON], QStringLiteral("tag")).toString()},
         {FMH::MODEL_KEY::MODIFIED, QDateTime::fromString(item.value(FMH::MODEL_NAME[FMH::MODEL_KEY::ADDDATE]).toString(), Qt::TextDate).toString()},
-        {FMH::MODEL_KEY::IS_DIR, "true"},
+        {FMH::MODEL_KEY::IS_DIR, QStringLiteral("true")},
         {FMH::MODEL_KEY::LABEL, label},
         {FMH::MODEL_KEY::TYPE, FMStatic::PathTypeLabel(FMStatic::PATHTYPE_KEY::TAGS_PATH)}};
 }
@@ -403,18 +415,18 @@ bool Tagging::toggleFav(const QUrl &url)
 
 bool Tagging::fav(const QUrl &url)
 {
-    return this->tagUrl(url.toString(), "fav", "#e91e63");
+    return this->tagUrl(url.toString(), QStringLiteral("fav"), QStringLiteral("#e91e63"));
 }
 
 bool Tagging::unFav(const QUrl &url) 
 {
-    return this->removeUrlTag(url.toString(), "fav");
+    return this->removeUrlTag(url.toString(), QStringLiteral("fav"));
 }
 
 bool Tagging::isFav(const QUrl &url, const bool &strict)
 {
     Q_UNUSED(strict)
     
-    return urlTagExists(url.toString(), "fav");
+    return urlTagExists(url.toString(), QStringLiteral("fav"));
 }
 
